==> jc-1.4.0.tar.gz: soot/util/EscapedReader.h <==
// public class soot.util.EscapedReader

// class file dependencies
// @dep_class cd1b0cd67de1a4a8 java_io_FilterReader
// @dep_class 688afb20bd4c4e01 java_io_Reader
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d340ba1fc04730c0 soot_util_EscapedReader

// header file dependencies
// @dep_header java_io_FilterReader

#include "java/io/FilterReader.h"

#ifndef _JC_soot_util_EscapedReader_H_
#define _JC_soot_util_EscapedReader_H_

// Forward structure declarations
struct _jc_java_io_Reader$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_soot_util_EscapedReader$sub_refs	_jc_soot_util_EscapedReader$sub_refs;
typedef struct _jc_soot_util_EscapedReader$sub_nonrefs	_jc_soot_util_EscapedReader$sub_nonrefs;
typedef struct _jc_soot_util_EscapedReader$refs	_jc_soot_util_EscapedReader$refs;
typedef struct _jc_soot_util_EscapedReader$nonrefs	_jc_soot_util_EscapedReader$nonrefs;
typedef struct _jc_soot_util_EscapedReader$object	_jc_soot_util_EscapedReader$object;

typedef const struct _jc_soot_util_EscapedReader$vmethods	_jc_soot_util_EscapedReader$vmethods;
typedef const struct _jc_soot_util_EscapedReader$vtable	_jc_soot_util_EscapedReader$vtable;
typedef const struct _jc_soot_util_EscapedReader$vtype	_jc_soot_util_EscapedReader$vtype;

// Constructors
extern void _jc_soot_util_EscapedReader$method$_init$cc321c4706192fe8(_jc_env *, struct _jc_soot_util_EscapedReader$object *, struct _jc_java_io_Reader$object *);

// Virtual methods
extern jint _jc_soot_util_EscapedReader$method$read$1a981297cb524963(_jc_env *, struct _jc_soot_util_EscapedReader$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_util_EscapedReader$method_info$read$1a981297cb524963;

// Virtual methods structure
struct _jc_soot_util_EscapedReader$vmethods {
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_soot_util_EscapedReader$object *);
};

// Vtable
struct _jc_soot_util_EscapedReader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_Reader$vmethods	java_io_Reader;
	_jc_java_io_FilterReader$vmethods	java_io_FilterReader;
	_jc_soot_util_EscapedReader$vmethods	soot_util_EscapedReader;
};

// Vtype
struct _jc_soot_util_EscapedReader$vtype {
	_jc_type			type;
	_jc_soot_util_EscapedReader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_EscapedReader$sub_refs {
	struct _jc_java_lang_StringBuffer$object	*mini;
};

// Reference instance fields (object)
struct _jc_soot_util_EscapedReader$refs {
    _jc_soot_util_EscapedReader$sub_refs	soot_util_EscapedReader;
    _jc_java_io_FilterReader$sub_refs	java_io_FilterReader;
    _jc_java_io_Reader$sub_refs	java_io_Reader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_EscapedReader$sub_nonrefs {
	jboolean	nextF;
	jint	nextch;
};

// Non-reference instance fields (object)
struct _jc_soot_util_EscapedReader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_Reader$sub_nonrefs	java_io_Reader;
    _jc_java_io_FilterReader$sub_nonrefs	java_io_FilterReader;
    _jc_soot_util_EscapedReader$sub_nonrefs	soot_util_EscapedReader;
};

// Object instance structure
struct _jc_soot_util_EscapedReader$object {
	_jc_soot_util_EscapedReader$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_EscapedReader$vtype	*vtype;
	_jc_soot_util_EscapedReader$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_EscapedReader$vtype _jc_soot_util_EscapedReader$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_EscapedReader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_EscapedReader$class_object;

#endif	/* _JC_soot_util_EscapedReader_H_ */

==> jc-1.4.6.tar.gz: soot/util/EscapedReader.h <==
// public class soot.util.EscapedReader

// class file dependencies
// @dep_class cd1b0cd67de1a4a8 java_io_FilterReader
// @dep_class 688afb20bd4c4e01 java_io_Reader
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d340ba1fc04730c0 soot_util_EscapedReader

// header file dependencies
// @dep_header java_io_FilterReader

#include "java/io/FilterReader.h"

#ifndef _JC_soot_util_EscapedReader_H_
#define _JC_soot_util_EscapedReader_H_

// Forward structure declarations
struct _jc_java_io_Reader$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_soot_util_EscapedReader$sub_refs	_jc_soot_util_EscapedReader$sub_refs;
typedef struct _jc_soot_util_EscapedReader$sub_nonrefs	_jc_soot_util_EscapedReader$sub_nonrefs;
typedef struct _jc_soot_util_EscapedReader$refs	_jc_soot_util_EscapedReader$refs;
typedef struct _jc_soot_util_EscapedReader$nonrefs	_jc_soot_util_EscapedReader$nonrefs;
typedef struct _jc_soot_util_EscapedReader$object	_jc_soot_util_EscapedReader$object;

typedef const struct _jc_soot_util_EscapedReader$vmethods	_jc_soot_util_EscapedReader$vmethods;
typedef const struct _jc_soot_util_EscapedReader$vtable	_jc_soot_util_EscapedReader$vtable;
typedef const struct _jc_soot_util_EscapedReader$vtype	_jc_soot_util_EscapedReader$vtype;

// Constructors
extern void _jc_soot_util_EscapedReader$method$_init$cc321c4706192fe8(_jc_env *, struct _jc_soot_util_EscapedReader$object *, struct _jc_java_io_Reader$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_util_EscapedReader$method$read$1a981297cb524963(_jc_env *, struct _jc_soot_util_EscapedReader$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_EscapedReader$method_info$read$1a981297cb524963;

// Virtual methods structure
struct _jc_soot_util_EscapedReader$vmethods {
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_soot_util_EscapedReader$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_EscapedReader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_Reader$vmethods	java_io_Reader;
	_jc_java_io_FilterReader$vmethods	java_io_FilterReader;
	_jc_soot_util_EscapedReader$vmethods	soot_util_EscapedReader;
};

// Vtype
struct _jc_soot_util_EscapedReader$vtype {
	_jc_type			type;
	_jc_soot_util_EscapedReader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_EscapedReader$sub_refs {
	struct _jc_java_lang_StringBuffer$object	*mini;
};

// Reference instance fields (object)
struct _jc_soot_util_EscapedReader$refs {
    _jc_soot_util_EscapedReader$sub_refs	soot_util_EscapedReader;
    _jc_java_io_FilterReader$sub_refs	java_io_FilterReader;
    _jc_java_io_Reader$sub_refs	java_io_Reader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_EscapedReader$sub_nonrefs {
	jboolean	nextF;
	jint	nextch;
};

// Non-reference instance fields (object)
struct _jc_soot_util_EscapedReader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_Reader$sub_nonrefs	java_io_Reader;
    _jc_java_io_FilterReader$sub_nonrefs	java_io_FilterReader;
    _jc_soot_util_EscapedReader$sub_nonrefs	soot_util_EscapedReader;
};

// Object instance structure
struct _jc_soot_util_EscapedReader$object {
	_jc_soot_util_EscapedReader$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_EscapedReader$vtype	*vtype;
	_jc_soot_util_EscapedReader$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_EscapedReader$vtype _jc_soot_util_EscapedReader$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_EscapedReader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_EscapedReader$class_object;

#endif	/* _JC_soot_util_EscapedReader_H_ */
